@@ -1,39 +1,26 @@
 /*
- * This file is part of KFileMetaData
- * Copyright (C) 2014 Vishesh Handa <me@vhanda.in>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    This file is part of KFileMetaData
+    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #ifndef KFILEMETADATA_PROPERTIES
 #define KFILEMETADATA_PROPERTIES
 
+#include "kfilemetadata_export.h"
+
 #include <QMap>
 #include <QVariant>
 
+/** @file properties.h <KFileMetaData/Properties> */
 namespace KFileMetaData {
 namespace Property {
 
 /**
  * @brief The Property enum contains all files property types that KFileMetaData manipulates
- *
- * @todo KF6 remove PropertyCount and LastProperty such that one can easily add new properties
  */
 enum Property {
-    FirstProperty = 0,
     Empty = 0,
 
     /**
@@ -69,7 +56,7 @@ enum Property {
     SampleRate,
 
     /**
-     * Represnts the track number in a set. Typically maps to the "TRCK" tag
+     * Represents the track number in a set. Typically maps to the "TRCK" tag
      * in IDv3
      */
     TrackNumber,
@@ -81,8 +68,8 @@ enum Property {
     ReleaseYear,
 
     /**
-     * Represents the Comment or Description stored in the file. This can map
-     * to the 'dc:description' tag from DublinCore or the "COMM" field from IDv3
+     * Represents a comment stored in the file. This can map
+     * to e.g. the "COMM" field from IDv3
      */
     Comment,
 
@@ -94,25 +81,25 @@ enum Property {
     Artist,
 
     /**
-     * Represnts the album of a media file. This generally corresponds
+     * Represents the album of a media file. This generally corresponds
      * to the IDv1 ALBUM tag.
      */
     Album,
 
     /**
-     * Represnts the album artist of a media file. This generally corresponds
+     * Represents the album artist of a media file. This generally corresponds
      * to the IDv3 TPE2 ("Band/Orchestra/Accompaniment") tag.
      */
     AlbumArtist,
 
     /**
-     * Represnts the Composer of a media file. This generally corresponds
+     * Represents the Composer of a media file. This generally corresponds
      * to the IDv2 COMPOSER tag.
      */
     Composer,
 
     /**
-     * Represnts the Lyricist of a media file. This generally corresponds
+     * Represents the Lyricist of a media file. This generally corresponds
      * to the IDv2 "Lyricist/text writer" tag.
      */
     Lyricist,
@@ -164,9 +151,9 @@ enum Property {
      * The language the document is written in. This directly maps to the
      * 'dc:language' tag from DublinCore. We do NOT employ any language
      * detection schemes on the text.
+     * @since 5.50
      */
-    //KF6 TODO: fix typo Langauge->Language
-    Langauge,
+    Language,
 
     /**
      * The copyright of the file. Represented as a string.
@@ -215,9 +202,20 @@ enum Property {
      */
     FrameRate,
 
-    // Images
-    ImageMake,
-    ImageModel,
+    /**
+     * The manufacturer of the equipment used for generating the file
+     * and metadata. Typically maps to the 'Exif.Image.Make' tag.
+     * @since 5.60
+     */
+    Manufacturer,
+
+    /**
+     * The model name of the equipment used for generating the file
+     * and metadata. Typically maps to the 'Exif.Image.Model' tag.
+     * @since 5.60
+     */
+    Model,
+
     ImageDateTime,
     ImageOrientation,
     PhotoFlash,
@@ -307,7 +305,7 @@ enum Property {
     Label,
 
     /**
-     * Containes the name of the compilation of an audio file.
+     * Contains the name of the compilation of an audio file.
      */
     Compilation,
 
@@ -316,37 +314,46 @@ enum Property {
      */
     License,
 
-    PropertyCount,
-    LastProperty = PropertyCount-1,
+    /**
+     * For ratings stored in Metadata tags
+     */
+    Rating,
+    /**
+     * Contains the lyrics of a song embedded in the file
+     */
+    Lyrics,
+    /**
+      * Contains ReplayGain information for audio files
+      */
+    ReplayGainAlbumPeak,
+    /**
+      * Contains ReplayGain information for audio files
+      * The album gain is given in "dB"
+      */
+    ReplayGainAlbumGain,
+    /**
+      * Contains ReplayGain information for audio files
+      */
+    ReplayGainTrackPeak,
+    /**
+      * Contains ReplayGain information for audio files
+      * The track gain is given in "dB"
+      */
+    ReplayGainTrackGain,
 
+    /**
+     * Represents the description stored in the file. This maps
+     * to the 'dc:description' tag from DublinCore
+     */
+    Description,
 };
 
 } // namespace Property
 
-typedef QMap<Property::Property, QVariant> PropertyMap;
-
-inline QVariantMap toVariantMap(const PropertyMap& propMap) {
-    QVariantMap varMap;
-    PropertyMap::const_iterator it = propMap.constBegin();
-    for (; it != propMap.constEnd(); ++it) {
-        int p = static_cast<int>(it.key());
-        varMap.insertMulti(QString::number(p), it.value());
-    }
-
-    return varMap;
-}
-
-inline PropertyMap toPropertyMap(const QVariantMap& varMap) {
-    PropertyMap propMap;
-    QVariantMap::const_iterator it = varMap.constBegin();
-    for (; it != varMap.constEnd(); ++it) {
-        int p = it.key().toInt();
-        propMap.insertMulti(static_cast<Property::Property>(p), it.value());
-    }
-
-    return propMap;
-}
+using PropertyMultiMap = QMultiMap<Property::Property, QVariant>;
 
 } // namespace KFileMetaData
 
+Q_DECLARE_METATYPE(KFileMetaData::Property::Property)
+
 #endif
