@@ -11,8 +11,12 @@
 #include <QVector>
 #include <QString>
 
+#include <memory>
+
 namespace KFileMetaData {
 
+class SimpleExtractionResultPrivate;
+
 /**
  * \class SimpleExtractionResult simpleextractionresult.h <KFileMetaData/SimpleExtractionResult>
  *
@@ -37,13 +41,16 @@ public:
     void addType(Type::Type type) override;
     void append(const QString& text) override;
 
-    PropertyMap properties() const;
+    /**
+     * Returns the properties of the extraction result.
+     */
+    PropertyMultiMap properties() const;
+
     QString text() const;
     QVector<Type::Type> types() const;
 
 private:
-    class Private;
-    Private* d;
+    const std::unique_ptr<SimpleExtractionResultPrivate> d;
 };
 
 }
